Metrics.
Metrics.
(get-all-metric-sample-sets!)(get-all-metric-sample-sets! a-metric-store)Return all metric-samples-sets within the given metric-store. If no metric-store is given, use the global metric store.
Return all metric-samples-sets within the given metric-store. If no metric-store is given, use the global metric store.
(get-metric-samples! metric labels)(get-metric-samples! a-metric-store metric labels)Return all metric-samples for a given metric within the given metric-store with the given labels.
Return all metric-samples for a given metric within the given metric-store with the given labels.
(prune-stale-metrics! time-ms)(prune-stale-metrics! a-metric-store time-ms)Prune all metrics in the a-metric-store that are older than time-ms. That is,
the last update time in ms of the metric value is smaller than time-ms.
If no metric-store is given, use the global metric store.
Prune all metrics in the `a-metric-store` that are older than `time-ms`. That is, the last update time in ms of the metric value is smaller than `time-ms`. If no metric-store is given, use the global metric store.
(record-and-get! metric labels value)(record-and-get! metric labels value last-update)(record-and-get! a-metric-store metric labels value last-update)Records a metric and returns a recent sample, which may or not reflect the metric just recorded.
Records a metric and returns a recent sample, which may or not reflect the metric just recorded.
(record-metric! metric labels value-value)(record-metric! metric labels value-value last-update)(record-metric! a-metric-store metric labels value-value last-update)Record a metric.
Record a metric.
(start-prune-stale-metrics-thread! & [stale-seconds every-seconds])Start a thread that prunes stale metrics older than stale-seconds seconds
every every-seconds seconds. If called without an argument, it prunes
metrics older than 24h every 5m.
Start a thread that prunes stale metrics older than `stale-seconds` seconds every `every-seconds` seconds. If called without an argument, it prunes metrics older than 24h every 5m.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |